@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2021-10-10 15:38:30
+@LastEditTime: 2021-11-17 15:05:29
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -60,7 +60,7 @@ class SyncPayOrderHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         is_log = bool(self.get_param("is_log", False))
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         app_key, app_secret = self.get_app_key_secret()
@@ -74,45 +74,34 @@ class SyncPayOrderHandler(ClientBaseHandler):
         invoke_result_data = order_base_model.sync_tao_pay_order(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, asset_type, goods_id, sku_id, ascription_type, app_key, app_secret, is_log, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(app_id, act_id, module_id, user_id, open_id, invoke_result_data)
+        ref_params = {}
+        ref_params["app_id"] = app_id
+        ref_params["act_id"] = act_id
+        ref_params["module_id"] = module_id
+        ref_params["user_id"] = user_id
+        ref_params["open_id"] = open_id
+
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"asset_type": 3, "goods_id": "", "sku_id": "", "ascription_type": 1, "check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
 
-    def business_process_executed(self, app_id, act_id, module_id, user_id, open_id, invoke_result_data):
+    def business_process_executed(self, result_data, ref_params):
         """
         :description: 执行后事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param open_id:open_id
-        :param invoke_result_data:框架处理结果
+        :param result_data:result_data
+        :param ref_params: 关联参数
         :return:
         :last_editors: HuangJianYi
         """
         stat_base_model = StatBaseModel(context=self)
         key_list_dict = {}
         key_list_dict["PayUserCount"] = 1
-        key_list_dict["PayCount"] = invoke_result_data.data["pay_num"]
-        key_list_dict["PayMoneyCount"] = invoke_result_data.data["pay_price"]
-        stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, open_id, key_list_dict)
-        return invoke_result_data
+        key_list_dict["PayCount"] = result_data.data["pay_num"]
+        key_list_dict["PayMoneyCount"] = result_data.data["pay_price"]
+        stat_base_model.add_stat_list(ref_params["app_id"], ref_params["act_id"], ref_params["module_id"], ref_params["user_id"], ref_params["open_id"], key_list_dict)
+        return result_data
 
 
 class PrizeOrderListHandler(ClientBaseHandler):
