@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2021-11-10 18:13:48
+@LastEditTime: 2021-11-17 15:13:36
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -57,30 +57,13 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
 
             # self.logging_link_info('小程序支付返回前端参数:' + str(invoke_result_data.data))
-            invoke_result_data = self.business_process_executed(invoke_result_data)
+            ref_params = {}
+            invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
             return self.response_json_success(invoke_result_data.data)
         except Exception as ex:
             self.logging_link_error("【创建微信预订单异常】" + traceback.format_exc())
             return self.response_json_error("fail", "请重新支付")
 
-    def business_process_executing(self):
-        """
-        :description: 执行前事件
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data):
-        """
-        :description: 执行后事件
-        :param invoke_result_data: invoke_result_data
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
 
 
 class WechatPayNotifyHandler(FrameBaseHandler):
@@ -123,7 +106,10 @@ class WechatPayNotifyHandler(FrameBaseHandler):
             invoke_result_data = self.business_process_executing()
             if invoke_result_data.success == False:
                 return self.write(wechat_pay_reponse.convert_response_xml(invoke_result_data.error_message, False))
-            self.business_process_executed(pay_order, response_result)
+            ref_params = {}
+            ref_params["pay_order"] = pay_order
+            ref_params["response_result"] = response_result
+            self.business_process_executed(invoke_result_data, ref_params)
 
             return self.write(wechat_pay_reponse.convert_response_xml("SUCCESS", True))
 
@@ -131,23 +117,17 @@ class WechatPayNotifyHandler(FrameBaseHandler):
             self.logging_link_error("【微信支付异步通知】" + traceback.format_exc() + ":" + str(xml_params))
             return self.write(wechat_pay_reponse.convert_response_xml("数据异常", False))
 
-    def business_process_executing(self):
-        """
-        :description: 执行前事件
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        return invoke_result_data
 
-    def business_process_executed(self, pay_order, response_result):
+    def business_process_executed(self, result_data, ref_params):
         """
         :description: 执行后事件
-        :param pay_order: 支付订单实体模型
-        :param response_result: 响应参数字典
+        :param result_data: result_data
+        :param ref_params: 关联参数
         :return:
         :last_editors: HuangJianYi
         """
+        response_result = ref_params["response_result"]
+        pay_order = ref_params["pay_order"]
         pay_order_model = PayOrderModel(context=self)
         transaction_id = response_result["transaction_id"]
         time_string = response_result["time_end"]
@@ -157,6 +137,8 @@ class WechatPayNotifyHandler(FrameBaseHandler):
             pay_order.pay_date = time.strftime("%Y-%m-%d %H:%M:%S", time.strptime(time_string, "%Y%m%d%H%M%S"))
             pay_order_model.update_entity(pay_order, "out_order_no,order_status,pay_date")
 
+        return result_data
+
 
 class WechatRefundNotifyHandler(FrameBaseHandler):
     """
@@ -179,28 +161,24 @@ class WechatRefundNotifyHandler(FrameBaseHandler):
             # 解密
             req_info_dict = wechat_refund_reponse.decode_req_info(response_result["req_info"])
             req_info_dict = req_info_dict["root"]
-            self.business_process_executed(req_info_dict)
+            ref_params = {}
+            ref_params["req_info_dict"] = req_info_dict
+            self.business_process_executed(invoke_result_data, ref_params)
             return self.write(wechat_refund_reponse.convert_response_xml("SUCCESS", True))
         except Exception as ex:
             self.logging_link_error("【微信退款异步通知】" + traceback.format_exc() + ":" + str(xml_params))
             return self.write(wechat_refund_reponse.convert_response_xml("数据异常", False))
 
-    def business_process_executing(self):
-        """
-        :description: 执行前事件
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        return invoke_result_data
 
-    def business_process_executed(self, req_info_dict):
+    def business_process_executed(self, result_data, ref_params):
         """
         :description: 执行后事件
-        :param req_info_dict: 退款解密信息
+        :param result_data: result_data
+        :param ref_params: 关联参数
         :return:
         :last_editors: HuangJianYi
         """
+        req_info_dict = ref_params["req_info_dict"]
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
         pay_order_model = PayOrderModel(db_transaction=db_transaction, context=self)
         refund_order_model = RefundOrderModel(db_transaction=db_transaction, context=self)
@@ -219,6 +197,8 @@ class WechatRefundNotifyHandler(FrameBaseHandler):
             db_transaction.rollback_transaction()
             self.logging_link_error("【微信退款异步通知数据处理异常】" + traceback.format_exc())
 
+        return result_data
+
 
 
 class TiktokVoucherOrderHandler(ClientBaseHandler):
@@ -263,30 +243,13 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
             # self.logging_link_info('小程序支付返回前端参数:' + str(invoke_result_data.data))
             pay_order_model.update_table("out_order_no=%s", "pay_order_no=%s", params=[invoke_result_data.data["order_id"], pay_order_no])
-            invoke_result_data = self.business_process_executed(invoke_result_data)
+            ref_params = {}
+            invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
             return self.response_json_success(invoke_result_data.data)
         except Exception as ex:
             self.logging_link_error("【创建抖音预订单异常】" + traceback.format_exc())
             return self.response_json_error("fail", "请重新支付")
 
-    def business_process_executing(self):
-        """
-        :description: 执行前事件
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data):
-        """
-        :description: 执行后事件
-        :param invoke_result_data: invoke_result_data
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
 
 
 class TiktokPayNotifyHandler(FrameBaseHandler):
@@ -325,7 +288,11 @@ class TiktokPayNotifyHandler(FrameBaseHandler):
             invoke_result_data = self.business_process_executing()
             if invoke_result_data.success == False:
                 return self.write(tiktok_reponse.convert_response_json(-1, invoke_result_data.error_message))
-            self.business_process_executed(pay_order, response_data)
+
+            ref_params = {}
+            ref_params["pay_order"] = pay_order
+            ref_params["response_data"] = response_data
+            self.business_process_executed(invoke_result_data, ref_params)
 
             return self.write(tiktok_reponse.convert_response_json())
 
@@ -333,37 +300,32 @@ class TiktokPayNotifyHandler(FrameBaseHandler):
             self.logging_link_error("【抖音支付异步通知】" + traceback.format_exc() + ":" + str(json_params))
             return self.write(tiktok_reponse.convert_response_json(-1, "数据异常"))
 
-    def business_process_executing(self):
-        """
-        :description: 执行前事件
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        return invoke_result_data
 
-    def business_process_executed(self, pay_order, respnse_data):
+    def business_process_executed(self, result_data, ref_params):
         """
         :description: 执行后事件
-        :param pay_order: 支付订单实体模型
-        :param respnse_data: 响应参数字典
+        :param result_data: result_data
+        :param ref_params: 关联参数
         :return:
         :last_editors: HuangJianYi
         """
+        pay_order = ref_params["pay_order"]
         pay_order_model = PayOrderModel(context=self)
         if pay_order.order_status == 0 or pay_order.order_status == 2:
             pay_time = SevenHelper.get_now_datetime()
             order_id = ""
             tiktok_pay_request = TikTokPayRequest()
-            invoke_result_data = tiktok_pay_request.query_order(pay_order.pay_order_no)
-            if invoke_result_data.success == True:
-                pay_time = invoke_result_data.data["payment_info"]["pay_time"]
-                order_id = invoke_result_data.data["order_id"]
+            query_invoke_result_data = tiktok_pay_request.query_order(pay_order.pay_order_no)
+            if query_invoke_result_data.success == True:
+                pay_time = query_invoke_result_data.data["payment_info"]["pay_time"]
+                order_id = query_invoke_result_data.data["order_id"]
             pay_order.order_status = 1
             pay_order.pay_date = pay_time
             pay_order.out_order_no = order_id if order_id else pay_order.out_order_no
             pay_order_model.update_entity(pay_order, "out_order_no,order_status,pay_date")
 
+        return result_data
+
 
 class TiktokRefundNotifyHandler(FrameBaseHandler):
     """
@@ -390,7 +352,10 @@ class TiktokRefundNotifyHandler(FrameBaseHandler):
             invoke_result_data = self.business_process_executing()
             if invoke_result_data.success == False:
                 return self.write(tiktok_reponse.convert_response_json(-1, invoke_result_data.error_message))
-            self.business_process_executed(refund_order, response_data)
+            ref_params = {}
+            ref_params["refund_order"] = refund_order
+            ref_params["response_data"] = response_data
+            self.business_process_executed(invoke_result_data, ref_params)
 
             return self.write(tiktok_reponse.convert_response_json())
 
@@ -398,23 +363,17 @@ class TiktokRefundNotifyHandler(FrameBaseHandler):
             self.logging_link_error("【抖音退款异步通知】" + traceback.format_exc() + ":" + str(json_params))
             return self.write(tiktok_reponse.convert_response_json(-1, "数据异常"))
 
-    def business_process_executing(self):
-        """
-        :description: 执行前事件
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        return invoke_result_data
 
-    def business_process_executed(self, refund_order, response_data):
+    def business_process_executed(self, result_data, ref_params):
         """
         :description: 执行后事件
-        :param refund_order: 退款订单信息
-        :param response_data: 响应数据
+        :param result_data: result_data
+        :param ref_params: 关联参数
         :return:
         :last_editors: HuangJianYi
         """
+        refund_order = ref_params["refund_order"]
+        response_data = ref_params["response_data"]
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
         pay_order_model = PayOrderModel(db_transaction=db_transaction, context=self)
         refund_order_model = RefundOrderModel(db_transaction=db_transaction, context=self)
@@ -431,4 +390,5 @@ class TiktokRefundNotifyHandler(FrameBaseHandler):
                 refund_order_model.update_table("refund_status=4", where="refund_no=%s", params=[response_data["cp_refundno"]])
         except Exception as ex:
             db_transaction.rollback_transaction()
-            self.logging_link_error("【抖音退款异步通知数据处理异常】" + traceback.format_exc())
\ No newline at end of file
+            self.logging_link_error("【抖音退款异步通知数据处理异常】" + traceback.format_exc())
+        return result_data
\ No newline at end of file
