@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-10 11:29:31
-@LastEditTime: 2021-10-10 15:39:51
+@LastEditTime: 2021-11-17 15:00:11
 @LastEditors: HuangJianYi
 @Description: 处理数据统计上报
 """
@@ -33,7 +33,7 @@ class ShareReportHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         stat_base_model = StatBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
@@ -42,42 +42,12 @@ class ShareReportHandler(ClientBaseHandler):
         invoke_result_data = stat_base_model.process_share_report(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, check_user_nick, continue_request_expire, is_stat)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class InviteReportHandler(ClientBaseHandler):
     """
@@ -102,7 +72,7 @@ class InviteReportHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         stat_base_model = StatBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
@@ -111,38 +81,8 @@ class InviteReportHandler(ClientBaseHandler):
         invoke_result_data = stat_base_model.process_invite_report(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, check_user_nick, continue_request_expire, is_stat)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
-
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
\ No newline at end of file
