@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-10-28 11:26:12
+@LastEditTime: 2021-11-17 15:28:07
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -33,33 +33,14 @@ class TaskInfoListHandler(ClientBaseHandler):
         is_log = self.get_param("is_log", False)
         task_base_model = TaskBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = self.business_process_executing(self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         daily_repeat_browse = invoke_result_data.data["daily_repeat_browse"] if invoke_result_data.data.__contains__("daily_repeat_browse") else False
         task_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log, daily_repeat_browse)
-        return self.response_json_success(self.business_process_executed(task_list, self.request_params))
+        ref_params = {}
+        return self.response_json_success(self.business_process_executed(task_list, ref_params))
 
-    def business_process_executing(self, request_params):
-        """
-        :description: 执行前事件
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"daily_repeat_browse": False}
-        return invoke_result_data
-
-    def business_process_executed(self, task_list, request_params):
-        """
-        :description: 执行后事件
-        :param task_list:任务列表
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return task_list
 
 
 class ReceiveRewardHandler(ClientBaseHandler):
@@ -88,7 +69,7 @@ class ReceiveRewardHandler(ClientBaseHandler):
         task_id = int(self.get_param("task_id", 0))
         task_sub_type = self.get_param("task_sub_type")
         task_base_model = TaskBaseModel(context=self)
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, task_id, task_sub_type, self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else False
@@ -98,46 +79,12 @@ class ReceiveRewardHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_receive_reward(app_id, act_id, module_id, user_id, login_token, task_id, task_sub_type, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, task_id, task_sub_type, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, task_id, task_sub_type, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param task_id:任务标识
-        :param task_sub_type:子任务类型
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, task_id, task_sub_type, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param task_id:任务标识
-        :param task_sub_type:子任务类型
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class FreeGiftHandler(ClientBaseHandler):
     """
@@ -162,7 +109,7 @@ class FreeGiftHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else True
@@ -172,42 +119,12 @@ class FreeGiftHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_free_gift(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_new_user":True,"check_user_nick":True,"continue_request_expire":5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data,app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class OneSignHandler(ClientBaseHandler):
     """
@@ -232,7 +149,7 @@ class OneSignHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else True
@@ -242,42 +159,12 @@ class OneSignHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_one_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_new_user": True, "check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class WeeklySignHandler(ClientBaseHandler):
     """
@@ -302,7 +189,7 @@ class WeeklySignHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else False
@@ -312,42 +199,12 @@ class WeeklySignHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_weekly_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_new_user": False, "check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class CumulativeSignHandler(ClientBaseHandler):
     """
@@ -372,7 +229,7 @@ class CumulativeSignHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else False
@@ -382,42 +239,12 @@ class CumulativeSignHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_cumulative_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_new_user, check_user_nick, continue_request_expire, is_stat)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token,request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_new_user": False, "check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class InviteNewUserHandler(ClientBaseHandler):
     """
@@ -444,7 +271,7 @@ class InviteNewUserHandler(ClientBaseHandler):
         invite_user_id = int(self.get_param("invite_user_id", 0))
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, invite_user_id, self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
@@ -452,44 +279,12 @@ class InviteNewUserHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_invite_new_user(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, invite_user_id, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, invite_user_id, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param invite_user_id:邀请用户标识
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, invite_user_id, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param invite_user_id:邀请用户标识
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class InviteJoinMemberHandler(ClientBaseHandler):
     """
@@ -516,7 +311,7 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         invite_user_id = int(self.get_param("invite_user_id", 0))
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token,invite_user_id,self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
@@ -525,44 +320,12 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, self.get_param("access_token"), app_key, app_secret, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, invite_user_id, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, invite_user_id, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param invite_user_id:邀请用户标识
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, invite_user_id, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param invite_user_id:邀请用户标识
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class CollectGoodsHandler(ClientBaseHandler):
     """
@@ -589,7 +352,7 @@ class CollectGoodsHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token,self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
@@ -597,42 +360,12 @@ class CollectGoodsHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_collect_goods(app_id, act_id, module_id, user_id, login_token, goods_id, self.__class__.__name__, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token,self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class BrowseGoodsHandler(ClientBaseHandler):
     """
@@ -659,7 +392,7 @@ class BrowseGoodsHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
@@ -668,42 +401,12 @@ class BrowseGoodsHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_browse_goods(app_id, act_id, module_id, user_id, login_token, goods_id, self.__class__.__name__, daily_repeat_browse, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"daily_repeat_browse":False,"check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class FavorStoreHandler(ClientBaseHandler):
     """
@@ -728,7 +431,7 @@ class FavorStoreHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
@@ -737,42 +440,12 @@ class FavorStoreHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_favor_store(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data,app_id, act_id, user_id, module_id, login_token,self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class JoinMemberHandler(ClientBaseHandler):
     """
@@ -797,7 +470,7 @@ class JoinMemberHandler(ClientBaseHandler):
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token,self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
@@ -806,42 +479,12 @@ class JoinMemberHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class BrowseSiteHandler(ClientBaseHandler):
     """
@@ -876,7 +519,7 @@ class BrowseSiteHandler(ClientBaseHandler):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token,self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
@@ -884,38 +527,9 @@ class BrowseSiteHandler(ClientBaseHandler):
         invoke_result_data = task_base_model.process_browse_site(app_id, act_id, module_id, user_id, login_token, task_type, task_sub_type, self.__class__.__name__, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, self.request_params)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token,request_params):
-        """
-        :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, request_params):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param login_token:访问令牌
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
