@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2021-11-11 16:30:31
+@LastEditTime: 2021-11-18 15:20:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -188,6 +188,7 @@ class FrameBaseHandler(BaseApiHandler):
         """
         self.http_response(self.json_dumps(rep_dic))
 
+
     def response_common(self, success=True, data=None, error_code="", error_message=""):
         """
         :description: 输出公共json模型
@@ -220,8 +221,8 @@ class FrameBaseHandler(BaseApiHandler):
                 template_value['dv'] = dv
             else:
                 template_value['data'] = data
-        template_value['error_code'] = error_code
-        template_value['error_message'] = error_message
+        template_value['error_code'] = "error" if not error_code and success == False else error_code
+        template_value['error_message'] = "系统异常" if not error_message and success == False else error_message
 
         rep_dic = {}
         rep_dic['success'] = True
@@ -538,6 +539,26 @@ class FrameBaseHandler(BaseApiHandler):
 
         operation_log_model.add_entity(operation_log)
 
+    def business_process_executing(self):
+        """
+        :description: 执行前事件
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {}
+        return invoke_result_data
+
+    def business_process_executed(self, result_data, ref_params):
+        """
+        :description: 执行后事件
+        :param result_data: result_data
+        :param ref_params: 关联参数
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return result_data
+
 
 class ClientBaseHandler(FrameBaseHandler):
     """
