@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-10-19 12:00:45
+@LastEditTime: 2021-11-19 09:58:19
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -62,11 +62,16 @@ class AddActInfoHandler(ClientBaseHandler):
         share_desc_json = self.get_param("share_desc_json", "")
         rule_desc_json = self.get_param("rule_desc_json", "")
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.add_act_info(app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.add.value, "act_info_tb", "AddActInfoHandler", None, self.json_dumps(invoke_result_data.data))
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success(invoke_result_data.data.id)
 
 
@@ -139,23 +144,18 @@ class UpdateActInfoHandler(ClientBaseHandler):
         d1 = self.get_param("d1", None)
         d2 = self.get_param("d2", None)
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.update_act_info(app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.update.value, "act_info_tb", "UpdateActInfoHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]))
-        self.business_process_executed(invoke_result_data)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success()
 
-    def business_process_executed(self, invoke_result_data):
-        """
-        :description: 执行后事件
-        :param invoke_result_data：执行后结果
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class ActInfoListHandler(ClientBaseHandler):
     """
@@ -178,6 +178,9 @@ class ActInfoListHandler(ClientBaseHandler):
         is_del = int(self.get_param("is_del", -1))
         act_name = self.get_param("act_name")
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
         if not app_id:
             return self.response_json_success({"data": []})
         act_base_model = ActBaseModel(context=self)
@@ -185,7 +188,8 @@ class ActInfoListHandler(ClientBaseHandler):
         for page in page_list:
             page["online_url"] = self.get_online_url(page['id'], app_id)
             page["live_url"] = self.get_live_url(app_id)
-        page_info = PageInfo(page_index, page_size, total, page_list)
+        ref_params = {}
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
 
 
@@ -204,6 +208,9 @@ class ActInfoHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         act_base_model = ActBaseModel(context=self)
         act_info_dict = act_base_model.get_act_info_dict(act_id,False)
         if act_info_dict:
@@ -215,7 +222,8 @@ class ActInfoHandler(ClientBaseHandler):
             act_info_dict["finish_menu_config_json"] = self.json_loads(act_info_dict["finish_menu_config_json"]) if act_info_dict["finish_menu_config_json"] else []
             act_info_dict['online_url'] = self.get_online_url(act_info_dict['id'], act_info_dict['app_id'])
             act_info_dict['live_url'] = self.get_live_url(act_info_dict['app_id'])
-        return self.response_json_success(act_info_dict)
+        ref_params = {}
+        return self.response_json_success(self.business_process_executed(act_info_dict, ref_params))
 
 
 class DeleteActInfoHandler(ClientBaseHandler):
@@ -233,11 +241,18 @@ class DeleteActInfoHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.update_act_info_status(app_id, act_id, 1)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.delete.value, "act_info_tb", "DeleteActInfoHandler", None, act_id)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
@@ -256,12 +271,18 @@ class ReviewActInfoHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.update_act_info_status(app_id, act_id, 0)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.review.value, "act_info_tb", "DeleteActInfoHandler", None, act_id)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
@@ -282,9 +303,15 @@ class ReleaseActInfoHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
         is_release = int(self.get_param("is_release", 0))
-
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.release_act_info(app_id, act_id, is_release)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
