@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 17:00:55
-@LastEditTime: 2021-09-14 19:46:23
+@LastEditTime: 2021-09-17 17:25:07
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,7 +15,7 @@ from aliyunsdkcore.client import AcsClient
 from aliyunsdkcore.request import CommonRequest
 
 
-class LeftNavigationHandler(TaoBaseHandler):
+class LeftNavigationHandler(ClientBaseHandler):
     """
     :description: 左侧导航栏
     """
@@ -26,13 +26,13 @@ class LeftNavigationHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         app_base_model = AppBaseModel(context=self)
-        invoke_result_data = app_base_model.get_left_navigation(self.get_taobao_param().user_nickm, self.get_taobao_param().access_token)
+        invoke_result_data = app_base_model.get_left_navigation(self.get_user_nick(), self.get_param("access_token"))
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
 
-class RightExplainHandler(TaoBaseHandler):
+class RightExplainHandler(ClientBaseHandler):
     """
     :description: 右侧各种教程和说明导航
     """
@@ -54,7 +54,7 @@ class RightExplainHandler(TaoBaseHandler):
         return self.response_json_success(course_info_list)
 
 
-class FriendLinkListHandler(TaoBaseHandler):
+class FriendLinkListHandler(ClientBaseHandler):
     """
     :description: 获取友情链接列表
     """
@@ -70,7 +70,7 @@ class FriendLinkListHandler(TaoBaseHandler):
         return self.response_json_success(friend_link_list)
 
 
-class SaasCustomHandler(TaoBaseHandler):
+class SaasCustomHandler(ClientBaseHandler):
     """
     :description: saas定制化信息获取
     """
@@ -81,7 +81,7 @@ class SaasCustomHandler(TaoBaseHandler):
         :return int
         :last_editors: HuangJianYi
         """
-        user_nick = self.get_taobao_param().user_nick
+        user_nick = self.get_user_nick()
         if not user_nick:
             return self.response_json_success(0)
         store_user_nick = user_nick.split(':')[0]
@@ -95,7 +95,7 @@ class SaasCustomHandler(TaoBaseHandler):
         return self.response_json_success(cloud_app_id)
 
 
-class SendSmsHandler(TaoBaseHandler):
+class SendSmsHandler(ClientBaseHandler):
     """
     :description: 发送短信
     """
@@ -106,7 +106,7 @@ class SendSmsHandler(TaoBaseHandler):
         :return 
         :last_editors: HuangJianYi
         """
-        open_id = self.get_taobao_param().open_id
+        open_id = self.get_open_id()
         thelephone = self.get_param("thelephone")
         client = AcsClient('LTAI4FwMYR1FBBui21t7cyh7', 'zyTM5zpYcL8lMXwtDgVoCfHgndoSKi', 'cn-hangzhou')
 
@@ -135,7 +135,7 @@ class SendSmsHandler(TaoBaseHandler):
         return self.response_json_success()
 
 
-class MarketingProgramListHandler(TaoBaseHandler):
+class MarketingProgramListHandler(ClientBaseHandler):
     """
     :description: 获取营销方案列表获取营销方案列表
     """
