@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-10-13 09:42:03
+@LastEditTime: 2021-11-19 09:53:03
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -78,7 +78,7 @@ class SaveActModuleHandler(ClientBaseHandler):
         s5 = self.get_param("s5")
         d1 = self.get_param("d1", "1900-01-01 00:00:00")
         d2 = self.get_param("d2", "1900-01-01 00:00:00")
-        invoke_result_data = self.business_process_executing(app_id, act_id, module_id, module_name, module_sub_name, start_date, end_date, module_pic, module_desc, price, price_gear_id, ip_id, join_ways, is_fictitious, sort_index, is_release, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         module_base_model = ModuleBaseModel(context=self)
@@ -90,45 +90,10 @@ class SaveActModuleHandler(ClientBaseHandler):
             self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveActModuleHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         else:
             self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActModuleHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         self.response_json_success(invoke_result_data.data["new"].id)
 
-    def business_process_executing(self, app_id, act_id, module_id, module_name, module_sub_name, start_date, end_date, module_pic, module_desc, price, price_gear_id, ip_id, join_ways, is_fictitious, sort_index, is_release, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2):
-        """
-        :description: 执行前事件
-        :param app_id: 应用标识
-        :param act_id: 活动标识
-        :param module_id: 活动模块标识
-        :param module_name: 模块名称
-        :param module_sub_name: 模块短名称
-        :param start_date: 开始时间
-        :param end_date: 结束时间
-        :param module_pic: 模块图片
-        :param module_desc: 描述信息
-        :param price: 价格
-        :param price_gear_id: 档位标识
-        :param ip_id: IP标识
-        :param join_ways: 活动参与条件（0所有1关注店铺2加入会员3指定用户）
-        :param is_fictitious: 是否开启虚拟中奖（1是0否）
-        :param sort_index: 排序
-        :param is_release: 是否发布（1是0否）
-        :param i1: i1
-        :param i2: i2
-        :param i3: i3
-        :param i4: i4
-        :param i5: i5
-        :param s1: s1
-        :param s2: s2
-        :param s3: s3
-        :param s4: s4
-        :param s5: s5
-        :param d1: d1
-        :param d2: d2
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        return invoke_result_data
-
 
 class ActModuleHandler(ClientBaseHandler):
     """
@@ -145,13 +110,17 @@ class ActModuleHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         module_id = int(self.get_param("module_id", 0))
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         module_base_model = ModuleBaseModel(context=self)
         act_module_dict = module_base_model.get_act_module_dict(module_id, False)
         if act_module_dict:
             if act_module_dict["app_id"] != app_id:
                 act_module_dict = {}
                 return self.response_json_success(act_module_dict)
-        return self.response_json_success(act_module_dict)
+        ref_params = {}
+        return self.response_json_success(self.business_process_executed(act_module_dict, ref_params))
 
 
 class ActModuleListHandler(ClientBaseHandler):
@@ -183,39 +152,21 @@ class ActModuleListHandler(ClientBaseHandler):
         condition = ""
         params = []
         order_by = "create_date desc"
-        invoke_result_data = self.business_process_executing(self.request_params)
-        if invoke_result_data.success == True:
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+        else:
             condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
             params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
             order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
-
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
         module_base_model = ModuleBaseModel(context=self)
         page_list, total = module_base_model.get_act_module_list(app_id, act_id, module_name, start_date, end_date, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params,is_cache=False)
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list))
+        ref_params = {}
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
 
-    def business_process_executing(self, request_params):
-        """
-        :description: 执行前事件
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {}
-        return invoke_result_data
-
-    def business_process_executed(self, page_list):
-        """
-        :description: 执行后事件
-        :param page_list:page_list
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return page_list
-
 
 class DeleteActModuleHandler(ClientBaseHandler):
     """
@@ -232,7 +183,7 @@ class DeleteActModuleHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         module_id = int(self.get_param("module_id", 0))
-        invoke_result_data = self.business_process_executing(app_id, module_id)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         module_base_model = ModuleBaseModel(context=self)
@@ -240,19 +191,12 @@ class DeleteActModuleHandler(ClientBaseHandler):
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.delete.value, "act_module_tb", "DeleteActModuleHandler", None, module_id)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success ==False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
-    def business_process_executing(self, app_id, module_id):
-        """
-        :description: 执行前事件
-        :param app_id: 应用标识
-        :param module_id: 活动模块标识
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        return invoke_result_data
-
 
 class ReviewActModuleHandler(ClientBaseHandler):
     """
@@ -269,7 +213,7 @@ class ReviewActModuleHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         module_id = int(self.get_param("module_id", 0))
-        invoke_result_data = self.business_process_executing(app_id, module_id)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         module_base_model = ModuleBaseModel(context=self)
@@ -277,19 +221,12 @@ class ReviewActModuleHandler(ClientBaseHandler):
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.review.value, "act_module_tb", "ReviewActModuleHandler", None, module_id)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success ==False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
-    def business_process_executing(self, app_id, module_id):
-        """
-        :description: 执行前事件
-        :param app_id: 应用标识
-        :param module_id: 活动模块标识
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        return invoke_result_data
-
 
 class ReleaseActModuleHandler(ClientBaseHandler):
     """
@@ -308,27 +245,19 @@ class ReleaseActModuleHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         module_id = int(self.get_param("module_id", 0))
         is_release = int(self.get_param("is_release", 0))
-        invoke_result_data = self.business_process_executing(app_id, module_id, is_release)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         module_base_model = ModuleBaseModel(context=self)
         invoke_result_data = module_base_model.release_act_module(app_id, module_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success ==False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
-    def business_process_executing(self, app_id, module_id, is_release):
-        """
-        :description: 执行前事件
-        :param app_id: 应用标识
-        :param module_id: 活动模块标识
-        :param is_release: 是否发布 1-是 0-否
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        return invoke_result_data
-
 
 class UpdateActModulePriceHandler(ClientBaseHandler):
     """
@@ -347,9 +276,15 @@ class UpdateActModulePriceHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
         prize_gear_id = int(self.get_param("prize_gear_id", 0))
-
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         module_base_model = ModuleBaseModel(context=self)
         invoke_result_data = module_base_model.update_act_module_price(app_id, act_id, prize_gear_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success ==False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
\ No newline at end of file
