@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-10-13 09:42:26
+@LastEditTime: 2021-11-19 09:30:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -144,7 +144,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
         condition = ""
         params = []
         order_by ="create_date desc"
-        invoke_result_data = self.business_process_executing(self.request_params)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == True:
             condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
             params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
@@ -152,16 +152,6 @@ class PrizeRosterListHandler(ClientBaseHandler):
         order_base_model = OrderBaseModel(context=self)
         return self.response_json_success(order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end,order_by=order_by, condition=condition,params=params,is_cache=False))
 
-    def business_process_executing(self,request_params):
-        """
-        :description: 执行前事件
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {"condition": "", "params": [], "order_by": "create_date desc"}
-        return invoke_result_data
 
 
 class UpdatePrizeOrderSellerRemarkHandler(ClientBaseHandler):
@@ -290,22 +280,23 @@ class PrizeOrderExportHandler(ClientBaseHandler):
 
         order_base_model = OrderBaseModel(context=self)
         prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=True, is_cache=False).data
-        result_data = self.business_process_executed(prize_order_list_dict, self.request_params)
+        ref_params = {}
+        result_data = self.business_process_executed(prize_order_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
         return self.response_json_success(resource_path)
 
-    def business_process_executed(self, prize_order_list_dict,request_params):
+    def business_process_executed(self, result_data,ref_params):
         """
         :description: 执行后事件
-        :param prize_order_list_dict:订单列表
-        :param request_params: 请求参数字典
+        :param result_data:result_data
+        :param ref_params: 关联参数
         :return:
         :last_editors: HuangJianYi
         """
-        result_data = []
-        if len(prize_order_list_dict) > 0:
+        result_list = []
+        if len(result_data) > 0:
             frame_base_model = FrameBaseModel(context=self)
-            for prize_order_dict in prize_order_list_dict:
+            for prize_order_dict in result_data:
                 for prize_roster_dict in prize_order_dict["roster_list"]:
                     data_row = {}
                     data_row["小程序订单号"] = prize_order_dict["order_no"]
@@ -331,8 +322,8 @@ class PrizeOrderExportHandler(ClientBaseHandler):
                     data_row["奖品价值"] = str(prize_roster_dict["prize_price"])
                     data_row["奖品规格"] = prize_roster_dict["sku_name"]
                     data_row["备注"] = prize_order_dict["seller_remark"]
-                    result_data.append(data_row)
-        return result_data
+                    result_list.append(data_row)
+        return result_list
 
 
 class PrizeRosterExportHandler(ClientBaseHandler):
@@ -383,20 +374,21 @@ class PrizeRosterExportHandler(ClientBaseHandler):
             prize_status = 1
         order_base_model = OrderBaseModel(context=self)
         prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end).data
-        result_data = self.business_process_executed(prize_roster_list_dict,self.request_params)
+        ref_params = {}
+        result_data = self.business_process_executed(prize_roster_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
         return self.response_json_success(resource_path)
 
-    def business_process_executed(self, prize_roster_list_dict, request_params):
+    def business_process_executed(self, result_data, ref_params):
         """
         :description: 执行后事件
-        :param prize_roster_list_dict:中奖记录列表
-        :param request_params: 请求参数字典
+        :param result_data:result_data
+        :param ref_params: 关联参数
         :return:
         :last_editors: HuangJianYi
         """
-        result_data = []
-        for prize_roster_dict in prize_roster_list_dict:
+        result_list = []
+        for prize_roster_dict in result_data:
             data_row = {}
             data_row["行为编号"] = prize_roster_dict["id"]
             data_row["小程序订单号"] = prize_roster_dict["order_no"]
@@ -412,5 +404,5 @@ class PrizeRosterExportHandler(ClientBaseHandler):
                 data_row["状态"] = "未下单"
             else:
                 data_row["状态"] = "已下单"
-            result_data.append(data_row)
-        return result_data
\ No newline at end of file
+            result_list.append(data_row)
+        return result_list
\ No newline at end of file
