@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-10-13 09:43:17
+@LastEditTime: 2021-11-19 10:07:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -105,6 +105,10 @@ class SaveActPrizeHandler(ClientBaseHandler):
         d1 = self.get_param("d1", "1900-01-01 00:00:00")
         d2 = self.get_param("d2", "1900-01-01 00:00:00")
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+
         prize_base_model = PrizeBaseModel(context=self)
         invoke_result_data = prize_base_model.save_act_prize(app_id, act_id, module_id, prize_id, prize_name, prize_title, prize_pic, prize_detail_json, goods_id, goods_code, goods_code_list, goods_type, prize_type, prize_price, probability, chance, prize_limit, is_prize_notice, prize_total, is_surplus, lottery_type, tag_name, tag_id, is_sku, sku_json, sort_index, is_release, ascription_type, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2)
         if invoke_result_data.success == False:
@@ -114,7 +118,8 @@ class SaveActPrizeHandler(ClientBaseHandler):
             self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveActPrizeHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         else:
             self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActPrizeHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
-
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success(invoke_result_data.data["new"].id)
 
 
@@ -146,7 +151,9 @@ class ActPrizeListHandler(ClientBaseHandler):
         params = []
         order_by = "create_date desc"
         invoke_result_data = self.business_process_executing()
-        if invoke_result_data.success == True:
+        if invoke_result_data.success == False:
+            return self.response_json_success({"data": []})
+        else:
             condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
             params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
             order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
@@ -155,28 +162,10 @@ class ActPrizeListHandler(ClientBaseHandler):
             return self.response_json_success({"data": []})
         prize_base_model = PrizeBaseModel(context=self)
         page_list, total = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params, is_cache=False)
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list))
+        ref_params = {}
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
 
-    def business_process_executing(self):
-        """
-        :description: 执行前事件
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {}
-        return invoke_result_data
-
-    def business_process_executed(self, page_list):
-        """
-        :description: 执行后事件
-        :param page_list:page_list
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return page_list
-
 
 class DeleteActPrizeHandler(ClientBaseHandler):
     """
@@ -193,11 +182,18 @@ class DeleteActPrizeHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         prize_id = int(self.get_param("prize_id", 0))
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         prize_base_model = PrizeBaseModel(context=self)
         invoke_result_data = prize_base_model.update_act_prize_status(app_id, prize_id, 1)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.delete.value, "act_prize_tb", "DeleteActPrizeHandler", None, prize_id)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
@@ -216,12 +212,18 @@ class ReviewActPrizeHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         prize_id = int(self.get_param("prize_id", 0))
-
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         prize_base_model = PrizeBaseModel(context=self)
         invoke_result_data = prize_base_model.update_act_prize_status(app_id, prize_id, 0)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.review.value, "act_prize_tb", "ReviewActPrizeHandler", None, prize_id)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
 
 
@@ -242,9 +244,15 @@ class ReleaseActPrizeHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         prize_id = int(self.get_param("prize_id", 0))
         is_release = int(self.get_param("is_release", 0))
-
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         prize_base_model = PrizeBaseModel(context=self)
         invoke_result_data = prize_base_model.release_act_prize(app_id, prize_id, is_release)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
\ No newline at end of file
