@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-11-16 13:44:20
-@LastEditTime: 2021-09-14 19:47:54
+@LastEditTime: 2021-11-19 09:28:59
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -34,18 +34,19 @@ class StatReportListHandler(ClientBaseHandler):
 
         stat_base_model = StatBaseModel(context=self)
         stat_report_list = stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date)
-        stat_report_list = self.business_process_executed(stat_report_list, self.request_params)
+        ref_params = {}
+        stat_report_list = self.business_process_executed(stat_report_list, ref_params)
         return self.response_json_success(stat_report_list)
 
-    def business_process_executed(self, stat_report_list, request_params):
+    def business_process_executed(self, result_data, ref_params):
         """
         :description: 执行后事件
-        :param stat_report_list:报表数据列表(表格)
-        :param request_params: 请求参数字典
+        :param result_data:result_data
+        :param ref_params: 关联参数
         :return:
         :last_editors: HuangJianYi
         """
-        return stat_report_list
+        return result_data
 
 
 class TrendReportListHandler(ClientBaseHandler):
@@ -72,15 +73,16 @@ class TrendReportListHandler(ClientBaseHandler):
 
         stat_base_model = StatBaseModel(context=self)
         trend_report_list = stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date)
-        trend_report_list = self.business_process_executed(trend_report_list, self.request_params)
+        ref_params = {}
+        trend_report_list = self.business_process_executed(trend_report_list, ref_params)
         return self.response_json_success(trend_report_list)
 
-    def business_process_executed(self, trend_report_list, request_params):
+    def business_process_executed(self, result_data, ref_params):
         """
         :description: 执行后事件
-        :param trend_report_list:报表数据列表(趋势图)
-        :param request_params: 请求参数字典
+        :param result_data:result_data
+        :param ref_params: 关联参数
         :return:
         :last_editors: HuangJianYi
         """
-        return trend_report_list
+        return result_data
