@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-10 10:05:38
-@LastEditTime: 2021-09-14 19:47:59
+@LastEditTime: 2021-11-19 09:34:24
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -83,7 +83,8 @@ class SaveTaskInfoHandler(ClientBaseHandler):
                     task_info_model.update_entity(task_info, "complete_type,task_name,sort_index,is_release,config_json,modify_date")
                     task_base_model._delete_task_info_dependency_key(0,task_info.id)
                     self.create_operation_log(OperationType.update.value, task_info.__str__(), "SaveTaskInfoHandler", SevenHelper.json_dumps(old_task_info.__dict__), SevenHelper.json_dumps(task_info.__dict__))
-                    self.business_process_executed(app_id, act_id, module_id, task_info)
+                    ref_params = {}
+                    self.business_process_executed(task_info, ref_params)
             else:
                 task_info = TaskInfo()
                 task_info.app_id = app_id
@@ -99,19 +100,10 @@ class SaveTaskInfoHandler(ClientBaseHandler):
                 task_info.modify_date = SevenHelper.get_now_datetime()
                 task_info_model.add_entity(task_info)
                 self.create_operation_log(OperationType.add.value, task_info.__str__(), "SaveTaskInfoHandler", None, SevenHelper.json_dumps(task_info))
-                self.business_process_executed(app_id, act_id, module_id, task_info)
+                ref_params = {}
+                self.business_process_executed(task_info, ref_params)
 
         task_base_model._delete_task_info_dependency_key(act_id)
 
         return self.response_json_success()
 
-    def business_process_executed(self, app_id, act_id, module_id, task_info):
-        """
-        :description: 执行后事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param task_info:任务信息
-        :return:
-        :last_editors: HuangJianYi
-        """
