@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2021-10-13 09:44:09
+@LastEditTime: 2021-11-19 09:35:22
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -122,28 +122,10 @@ class UpdateUserStatusByBlackHandler(ClientBaseHandler):
         invoke_result_data = user_base_model.update_user_state_by_black(app_id, act_id, user_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
-        self.business_process_executed(invoke_result_data)
+        ref_params = {}
+        self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success()
 
-    def business_process_executing(self):
-        """
-        :description: 执行前事件
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class AuditUserBlackHandler(ClientBaseHandler):
     """
@@ -171,28 +153,10 @@ class AuditUserBlackHandler(ClientBaseHandler):
         invoke_result_data = user_base_model.audit_user_black(app_id, black_id, audit_status, audit_remark)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
-        self.business_process_executed(invoke_result_data)
+        ref_params = {}
+        self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success()
 
-    def business_process_executing(self):
-        """
-        :description: 执行前事件
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
-
 
 class UpdateAuditRemarkHandler(ClientBaseHandler):
     """
@@ -290,33 +254,10 @@ class UpdateUserAssetHandler(ClientBaseHandler):
         invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], asset_type, asset_value, asset_object_id, 3, "", "手动配置", "手动配置")
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
-        self.business_process_executed(invoke_result_data)
+        ref_params = {}
+        self.business_process_executed(invoke_result_data, ref_params)
         return self.response_json_success()
 
-    def business_process_executing(self):
-        """
-        :description: 执行前事件
-        :return:
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        invoke_result_data.data = {}
-        return invoke_result_data
-
-    def business_process_executed(self, invoke_result_data):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :param app_id：应用标识
-        :param act_id：活动标识
-        :param module_id：活动模块标识
-        :param open_id：open_id
-        :param user_nick：昵称
-        :param avatar：头像
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return invoke_result_data
 
 
 class BatchUpdateUserAssetHandler(ClientBaseHandler):
@@ -434,14 +375,5 @@ class UserInfoListHandler(ClientBaseHandler):
         end_date = self.get_param("end_date")
         user_base_model = UserBaseModel(context=self)
         page_info = user_base_model.get_user_list(app_id, act_id, page_size, page_index, user_state, user_id, start_date, end_date, user_nick, open_id)
-        return self.reponse_json_success(self.business_process_executed(page_info, self.request_params))
-
-    def business_process_executed(self, page_info, request_params):
-        """
-        :description: 执行后事件
-        :param page_info:用户信息分页实体模型
-        :param request_params: 请求参数字典
-        :return:
-        :last_editors: HuangJianYi
-        """
-        return page_info
\ No newline at end of file
+        ref_params = {}
+        return self.reponse_json_success(self.business_process_executed(page_info, ref_params))
\ No newline at end of file
