@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-10-15 11:48:24
+@LastEditTime: 2021-11-11 10:53:40
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -21,7 +21,7 @@ class SevenHelper:
     :description: 常用帮助类 提供常用方法 如：字典列表合并、请求太频繁校验、（入队列、出队列、校验队列长度 主要用于流量削峰场景）、创建分布式锁、释放分布式锁、序列化、反序列化、生成订单号等
     """
     @classmethod
-    def redis_init(self, db=None, decode_responses=True):
+    def redis_init(self, db=None, config_dict=None, decode_responses=True):
         """
         :description: redis初始化
         :return: redis_cli
@@ -32,7 +32,7 @@ class SevenHelper:
         if not db:
             db = config.get_value("redis")["db"]
         password = config.get_value("redis")["password"]
-        redis_cli = RedisHelper.redis_init(host, port, db, password, decode_responses=decode_responses)
+        redis_cli = RedisHelper.redis_init(host, port, db, password, config_dict=config_dict, decode_responses=decode_responses)
         return redis_cli
 
     @classmethod
@@ -60,12 +60,12 @@ class SevenHelper:
          :return: bool False-代表达到长度限制，进行拦截
          :last_editors: HuangJianYi
          """
-        redis_init = SevenHelper.redis_init()
+        redis_init = self.redis_init()
         list_len = redis_init.llen(queue_name)
         if int(list_len) >= int(queue_lenth):
-            return False
-        else:
             return True
+        else:
+            return False
 
     @classmethod
     def redis_lpush(self, queue_name, value, expire):
@@ -77,7 +77,7 @@ class SevenHelper:
          :return:
          :last_editors: HuangJianYi
          """
-        redis_init = SevenHelper.redis_init()
+        redis_init = self.redis_init()
         redis_init.lpush(queue_name, json.dumps(value))
         redis_init.expire(queue_name,expire)
 
@@ -89,11 +89,11 @@ class SevenHelper:
          :return: 
          :last_editors: HuangJianYi
          """
-        result = SevenHelper.redis_init().lpop(queue_name)
+        result = self.redis_init().lpop(queue_name)
         return result
 
     @classmethod
-    def redis_acquire_lock(self, lock_name, acquire_time=10, time_out=15):
+    def redis_acquire_lock(self, lock_name, acquire_time=3, time_out=4):
         """
         :description: 创建分布式锁
         :param lock_name：锁定名称
@@ -105,7 +105,7 @@ class SevenHelper:
         identifier = str(uuid.uuid4())
         end = time.time() + acquire_time
         lock = "lock:" + lock_name
-        redis_init = SevenHelper.redis_init()
+        redis_init = self.redis_init()
         while time.time() < end:
             if redis_init.setnx(lock, identifier):
                 # 给锁设置超时时间, 防止进程崩溃导致其他进程无法获取锁
@@ -126,7 +126,7 @@ class SevenHelper:
         :last_editors: HuangJianYi
         """
         lock = "lock:" + lock_name
-        redis_init = SevenHelper.redis_init()
+        redis_init = self.redis_init()
         pip = redis_init.pipeline(True)
         while True:
             try:
@@ -431,8 +431,10 @@ class SevenHelper:
         :return: str
         :last_editors: HuangJianYi
         """
-        if isinstance(rep_dic, str):
+        try:
             rep_dic = ast.literal_eval(rep_dic)
+        except ValueError:
+            pass
         if hasattr(rep_dic, '__dict__'):
             rep_dic = rep_dic.__dict__
         return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder, default=lambda x: (x.__dict__ if not isinstance(x, datetime.datetime) else datetime.datetime.strftime(x, '%Y-%m-%d %H:%M:%S')) if not isinstance(x, decimal.Decimal) else float(x), sort_keys=False, indent=1)
@@ -463,4 +465,4 @@ class SevenHelper:
         if not sub_count:
             return sub_table
         sub_table = str(object_id % sub_count)
-        return sub_table
+        return sub_table
\ No newline at end of file
