@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-09-29 17:00:07
+@LastEditTime: 2021-10-13 17:13:18
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -22,6 +22,21 @@ class AssetBaseModel():
     def __init__(self, context, logging_error=None):
         self.context = context
         self.logging_link_error = logging_error
+    
+    def _delete_asset_dependency_key(self,act_id,user_id):
+        """
+        :description: 删除资产依赖建
+        :param act_id: 活动标识
+        :param user_id: 用户标识
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        try:
+            redis_init = SevenHelper.redis_init()
+            if act_id and user_id:
+                redis_init.delete(f"asset_log_list:actid_{act_id}_userid_{user_id}")
+        except Exception as ex:
+            pass
 
     def _add_onlyid_warn_stat(self,handler_name):
         """
@@ -160,6 +175,12 @@ class AssetBaseModel():
                 old_user_asset_id = user_asset.id
                 history_asset_value = user_asset.asset_value
             else:
+                if asset_value < 0:
+                    SevenHelper.redis_release_lock(acquire_lock_name, identifier)
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = "no_enough"
+                    invoke_result_data.error_message = "资产不能为负数"
+                    return invoke_result_data
                 user_asset = UserAsset()
                 user_asset.id_md5 = user_asset_id_md5
                 user_asset.app_id = app_id
@@ -177,7 +198,7 @@ class AssetBaseModel():
 
             old_asset_inventory_id = 0
             asset_inventory_id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}_{now_day_int}")
-            asset_inventory = asset_inventory_model.get_entity("id_md5=%s",params=[asset_inventory_id_md5])
+            asset_inventory = asset_inventory_model.get_cache_entity("id_md5=%s",params=[asset_inventory_id_md5])
             asset_inventory_update_sql = f"process_count=0,now_value={user_asset.asset_value}"
             if asset_inventory:
                 old_asset_inventory_id = asset_inventory.id
@@ -267,14 +288,14 @@ class AssetBaseModel():
             if only_id:
                 redis_init.hset(only_cache_key, only_id, 1)
                 redis_init.expire(only_cache_key, 24 * 3600)
-
+            self._delete_asset_dependency_key(act_id,user_id)
             invoke_result_data.data = {"user_asset":user_asset.__dict__}
 
         except Exception as ex:
             if self.context:
-                self.context.logging_link_error("【变更资产】" + str(ex))
+                self.context.logging_link_error("【变更资产】" + traceback.format_exc())
             elif self.logging_link_error:
-                self.logging_link_error("【变更资产】" + str(ex))
+                self.logging_link_error("【变更资产】" + traceback.format_exc())
             if db_transaction.is_transaction == True:
                 db_transaction.rollback_transaction()
             invoke_result_data.success = False
@@ -306,7 +327,7 @@ class AssetBaseModel():
             if ',' in str(user_ids):
                 condition += f" AND user_id in ({user_ids})"
             elif isinstance(user_ids,list):
-                condition+=" AND" + SevenHelper.get_condition_by_int_list("user_id",user_ids)
+                condition+=" AND " + SevenHelper.get_condition_by_int_list("user_id",user_ids)
             else:
                 condition += " AND user_id=%s"
                 params.append(user_ids)
@@ -345,7 +366,7 @@ class AssetBaseModel():
                 user_asset_dict["asset_value"] = 0
         return user_asset_dict
 
-    def get_asset_log_list(self, app_id, act_id, asset_type, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id="", field="*"):
+    def get_asset_log_list(self, app_id, act_id, asset_type, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id="", field="*",is_cache=True):
         """
         :description: 获取用户资产流水记录
         :param app_id：应用标识
@@ -362,6 +383,7 @@ class AssetBaseModel():
         :param source_type：来源类型（1-购买2-任务3-手动配置4-抽奖5-回购）
         :param source_object_id：来源对象标识(比如来源类型是任务则对应任务类型)
         :param field：查询字段
+        :param is_cache：是否缓存
         :return: 返回PageInfo
         :last_editors: HuangJianYi
         """
@@ -400,10 +422,14 @@ class AssetBaseModel():
             condition += " AND source_object_id=%s"
             params.append(source_object_id)
         sub_table = SevenHelper.get_sub_table(act_id,config.get_value("asset_sub_table_count",0))
-        page_list, total = AssetLogModel(sub_table=sub_table, context=self.context).get_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params)
+        asset_log_model = AssetLogModel(sub_table=sub_table, context=self.context)
+        if is_cache:
+            page_list, total = asset_log_model.get_cache_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params,dependency_key=f"asset_log_list:actid_{act_id}_userid_{user_id}")
+        else:
+            page_list, total = asset_log_model.get_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params)
         if len(page_list) > 0:
             for item in page_list:
-                item["create_day"] = item["create_date"].strftime('%Y-%m-%d')
+                item["create_day"] = TimeHelper.format_time_to_datetime(str(item["create_date"])).strftime('%Y-%m-%d')
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
