@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2021-10-12 17:56:39
+@LastEditTime: 2021-10-29 13:42:20
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -32,11 +32,9 @@ class StatConsoleModel():
             self._start_process_stat_queue(None, mod_count)
 
         else:
-
             for i in range(sub_table_count):
 
-                t = multiprocessing.Process(target=self._start_process_stat_queue, args=[str(i), mod_count])
-                t.start()
+                self._start_process_stat_queue(str(i), mod_count)
 
     def _start_process_stat_queue(self, sub_table, mod_count):
 
@@ -56,6 +54,8 @@ class StatConsoleModel():
         """
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
         stat_queue_model = StatQueueModel(sub_table=sub_table, db_transaction=db_transaction)
+        del_stat_queue_sub_table = sub_table + "_del" if sub_table else "del"
+        del_stat_queue_model = StatQueueModel(sub_table=del_stat_queue_sub_table, db_transaction=db_transaction)
         stat_log_model = StatLogModel(sub_table=sub_table, db_transaction=db_transaction)
         stat_report_model = StatReportModel(sub_table=sub_table,db_transaction=db_transaction)
         stat_orm_model = StatOrmModel()
@@ -63,27 +63,24 @@ class StatConsoleModel():
         while True:
             try:
                 now_date = TimeHelper.get_now_format_time()
-                now_day_int = SevenHelper.get_now_day_int()
-                now_month_int = SevenHelper.get_now_month_int()
-                now_year_int = SevenHelper.get_now_int(fmt='%Y')
                 stat_queue_list = stat_queue_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and process_count<10 and '{now_date}'>process_date", order_by="process_date asc", limit="100")
                 if len(stat_queue_list) > 0:
                     for stat_queue in stat_queue_list:
                         try:
                             stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_queue.key_name])
                             if not stat_orm:
-                                stat_queue.process_count += 1
-                                stat_queue.process_result = "orm不存在"
-                                minute = 1 if stat_queue.process_count <= 5 else 5
-                                stat_queue.process_date = TimeHelper.add_minutes_by_format_time(minute=minute)
-                                stat_queue_model.update_entity(stat_queue, "process_count,process_result,process_date")
+                                stat_queue_model.del_entity("id=%s", params=[stat_queue.id])
                                 continue
+                            create_date = TimeHelper.format_time_to_datetime(stat_queue.create_date)
+                            create_day_int = int(create_date.strftime('%Y%m%d'))
+                            create_month_int = int(create_date.strftime('%Y%m'))
+                            create_year_int = int(create_date.strftime('%Y'))
                             is_add = True
                             if stat_orm.repeat_type > 0:
                                 if stat_orm.repeat_type == 2:
                                     stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id])
                                 else:
-                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, now_day_int])
+                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, create_day_int])
                                 if stat_log_total > 0:
                                     is_add = False
 
@@ -95,12 +92,12 @@ class StatConsoleModel():
                             stat_log.user_id = stat_queue.user_id
                             stat_log.open_id = stat_queue.open_id
                             stat_log.key_value = stat_queue.key_value
-                            stat_log.create_day = now_day_int
-                            stat_log.create_month = now_month_int
-                            stat_log.create_date = now_date
+                            stat_log.create_day = create_day_int
+                            stat_log.create_month = create_month_int
+                            stat_log.create_date = create_date
 
                             stat_report_condition = "act_id=%s and module_id=%s and key_name=%s and create_day=%s"
-                            stat_report_param = [stat_queue.act_id, stat_queue.module_id, stat_queue.key_name, now_day_int]
+                            stat_report_param = [stat_queue.act_id, stat_queue.module_id, stat_queue.key_name, create_day_int]
                             stat_report_total = stat_report_model.get_cache_total(stat_report_condition, params=stat_report_param)
 
                             db_transaction.begin_transaction()
@@ -112,20 +109,22 @@ class StatConsoleModel():
                                     stat_report.module_id = stat_queue.module_id
                                     stat_report.key_name = stat_queue.key_name
                                     stat_report.key_value = stat_queue.key_value
-                                    stat_report.create_date = now_date
-                                    stat_report.create_year = now_year_int
-                                    stat_report.create_month = now_month_int
-                                    stat_report.create_day = now_day_int
+                                    stat_report.create_date = create_date
+                                    stat_report.create_year = create_year_int
+                                    stat_report.create_month = create_month_int
+                                    stat_report.create_day = create_day_int
                                     stat_report_model.add_entity(stat_report)
                                 else:
                                     stat_report_model.update_table(f"key_value=key_value+{stat_queue.key_value}", stat_report_condition, params=stat_report_param)
                             stat_log_model.add_entity(stat_log)
                             stat_queue_model.del_entity("id=%s", params=[stat_queue.id])
+                            del_stat_queue_model.add_entity(stat_queue)
                             db_transaction.commit_transaction()
 
                         except Exception as ex:
                             logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{traceback.format_exc()}")
-                            db_transaction.rollback_transaction()
+                            if db_transaction.is_transaction == True:
+                                db_transaction.rollback_transaction()
                             stat_queue.process_count += 1
                             stat_queue.process_result = f"出现异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{traceback.format_exc()}"
                             minute = 1 if stat_queue.process_count <= 5 else 5
@@ -135,4 +134,5 @@ class StatConsoleModel():
                 else:
                     time.sleep(int(config.get_value("stat_sleep_time", 1)))
             except Exception as ex:
-                time.sleep(10)
+                logger_error.error(f"统计队列{mod_value}异常,ex:{traceback.format_exc()}")
+                time.sleep(5)
