@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-09-17 19:59:06
+@LastEditTime: 2021-11-02 18:56:50
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -27,6 +27,8 @@ def seven_cloudapp_frame_route():
         (r"/client/asset_log_list", user.AssetLogListHandler),  #用户资产流水列表
         (r"/client/get_join_member_url", user.GetJoinMemberUrlHandler),  #加入会员地址
         (r"/client/get_coupon_prize", user.GetCouponPrizeHandler),  #领取淘宝优惠券
+        (r"/client/user_address_list", user.UserAddressListHandler),  #收货地址列表
+        (r"/client/save_user_address", user.SaveUserAddressHandler),  #保存收货地址
         (r"/client/theme_info", theme.ThemeInfoHandler),  #主题信息
         (r"/client/save_theme", theme.SaveThemeHandler),  #保存主题信息，由前端通过工具进行保存
         (r"/client/save_skin", theme.SaveSkinHandler),  #保存皮肤信息，由前端通过工具进行保存
@@ -60,11 +62,11 @@ def seven_cloudapp_frame_route():
         (r"/client/share_report", stat.ShareReportHandler),  #分享统计上报
         (r"/client/invite_report", stat.InviteReportHandler),  #邀请进入统计上报
         (r"/client/wvoucher_order", pay.WechatVoucherOrderHandler),  #创建微信预订单
-        (r"/client/wpay_notify", pay.WechatPayNotifyHandler),  #微信支付异步同步
-        (r"/client/wrefund_notify", pay.WechatRefundNotifyHandler),  #微信退款异步同步
+        (r"/client/wpay_notify", pay.WechatPayNotifyHandler),  #微信支付异步通知
+        (r"/client/wrefund_notify", pay.WechatRefundNotifyHandler),  #微信退款异步通知
         (r"/client/tvoucher_order", pay.TiktokVoucherOrderHandler),  #创建抖音预订单
-        (r"/client/tpay_notify", pay.TiktokPayNotifyHandler),  #抖音支付异步同步
-        (r"/client/trefund_notify", pay.TiktokRefundNotifyHandler),  #抖音退款异步同步
+        (r"/client/tpay_notify", pay.TiktokPayNotifyHandler),  #抖音支付异步通知
+        (r"/client/trefund_notify", pay.TiktokRefundNotifyHandler),  #抖音退款异步通知
 
         #后台和千牛端
         (r"/server/saas_custom", base_s.SaasCustomHandler),  #saas定制化信息获取
